@@ -307,11 +307,9 @@ where
                     {
                         proposed_node.endpoints.push(endpoint);
                     } else {
-                        #[allow(unused_mut)]
                         let mut proposed_node =
                             ProposedNodeBuilder::new().with_node_id(&node.node_id);
 
-                        #[cfg(feature = "challenge-authorization")]
                         if let Some(public_key) = &node.public_key {
                             proposed_node = proposed_node.with_public_key(public_key)
                         }
