@@ -105,7 +105,6 @@ impl ServiceInstances for RoutingTableServiceInstances {
 
         service.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id(&component_id),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id(&self.node_id),
         ));
 
@@ -153,7 +152,6 @@ impl ServiceInstances for RoutingTableServiceInstances {
 mod tests {
     use super::*;
 
-    #[cfg(feature = "challenge-authorization")]
     use crate::circuit::routing::AuthorizationType;
     use crate::circuit::routing::{
         memory::RoutingTable, Circuit, CircuitNode, RoutingTableWriter, Service,
@@ -226,7 +224,6 @@ mod tests {
             .expect("Missing service");
         service.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("abc_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("123"),
         ));
 
@@ -277,7 +274,6 @@ mod tests {
                 .peer_id(),
             &Some(PeerTokenPair::new(
                 PeerAuthorizationToken::from_peer_id("my_component"),
-                #[cfg(feature = "challenge-authorization")]
                 PeerAuthorizationToken::from_peer_id("123"),
             ))
         );
@@ -330,7 +326,6 @@ mod tests {
             .expect("Missing service");
         service.set_peer_id(PeerTokenPair::new(
             PeerAuthorizationToken::from_peer_id("abc_network"),
-            #[cfg(feature = "challenge-authorization")]
             PeerAuthorizationToken::from_peer_id("123"),
         ));
 
@@ -354,18 +349,8 @@ mod tests {
     }
 
     fn build_circuit() -> (Circuit, Vec<CircuitNode>) {
-        let node_123 = CircuitNode::new(
-            "123".to_string(),
-            vec!["123.0.0.1:0".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
-        let node_345 = CircuitNode::new(
-            "345".to_string(),
-            vec!["123.0.0.1:1".to_string()],
-            #[cfg(feature = "challenge-authorization")]
-            None,
-        );
+        let node_123 = CircuitNode::new("123".to_string(), vec!["123.0.0.1:0".to_string()], None);
+        let node_345 = CircuitNode::new("345".to_string(), vec!["123.0.0.1:1".to_string()], None);
 
         let service_abc = Service::new(
             "abc".to_string(),
@@ -385,7 +370,6 @@ mod tests {
             "alpha".into(),
             vec![service_abc.clone(), service_def.clone()],
             vec!["123".into(), "345".into()],
-            #[cfg(feature = "challenge-authorization")]
             AuthorizationType::Trust,
         );
 
