@@ -1,4 +1,4 @@
-// Copyright 2018-2020 Cargill Incorporated
+// Copyright 2018-2021 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -25,11 +25,7 @@ pub struct KeyPermissionError {
 
 impl std::error::Error for KeyPermissionError {
     fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
-        if let Some(ref err) = self.source {
-            Some(&**err)
-        } else {
-            None
-        }
+        self.source.as_deref()
     }
 }
 
