@@ -17,7 +17,6 @@ use crate::network::connection_manager::{
 };
 use crate::transport::Connection;
 
-#[cfg(feature = "challenge-authorization")]
 use super::ConnectionAuthorizationType;
 use super::{AuthorizationConnector, AuthorizationManagerError, ConnectionAuthorizationState};
 
@@ -27,19 +26,13 @@ impl Authorizer for AuthorizationConnector {
         connection_id: String,
         connection: Box<dyn Connection>,
         callback: AuthorizerCallback,
-        #[cfg(feature = "challenge-authorization")] expected_authorization: Option<
-            ConnectionAuthorizationType,
-        >,
-        #[cfg(feature = "challenge-authorization")] local_authorization: Option<
-            ConnectionAuthorizationType,
-        >,
+        expected_authorization: Option<ConnectionAuthorizationType>,
+        local_authorization: Option<ConnectionAuthorizationType>,
     ) -> Result<(), AuthorizerError> {
         self.add_connection(
             connection_id,
             connection,
-            #[cfg(feature = "challenge-authorization")]
             expected_authorization,
-            #[cfg(feature = "challenge-authorization")]
             local_authorization,
             Box::new(move |state| (*callback)(state.into())),
         )
@@ -54,17 +47,13 @@ impl From<ConnectionAuthorizationState> for AuthorizationResult {
                 connection_id,
                 connection,
                 identity,
-                #[cfg(feature = "challenge-authorization")]
                 expected_authorization,
-                #[cfg(feature = "challenge-authorization")]
                 local_authorization,
             } => AuthorizationResult::Authorized {
                 connection_id,
                 connection,
                 identity,
-                #[cfg(feature = "challenge-authorization")]
                 expected_authorization,
-                #[cfg(feature = "challenge-authorization")]
                 local_authorization,
             },
 
