@@ -36,7 +36,14 @@ impl NodeIdStore for FileNodeIdStore {
     fn get_node_id(&self) -> Result<Option<String>, NodeIdStoreError> {
         fs::read_to_string(&self.filename)
             .map_err(|e| e.into())
-            .map(|s| Some(s.trim_end().to_string()))
+            .map(|s| {
+                let id = s.trim_end().to_string();
+                if !id.is_empty() {
+                    Some(id)
+                } else {
+                    None
+                }
+            })
     }
 
     fn set_node_id(&self, node_id: String) -> Result<(), NodeIdStoreError> {
